@@ -3,7 +3,7 @@
 #include <orbit/orbit.h>
 #include "orb-core-private.h"
 
-/**
+/***
     The argument {mem} is a chuck of memory described by {tc}, and its
     contents is freed, but {mem} itself is not freed. That is, if {mem}
     contains anything interesting (objrefs, pointers), they are freed.
@@ -306,6 +306,9 @@ ORBit_realloc_tcval (gpointer       old,
 	if (!num_elements)
 		return NULL;
 
+	if (!old_num_elements && !old)
+		return ORBit_alloc_tcval (tc, num_elements);
+
 	if (!(element_size = ORBit_gather_alloc_info (tc)))
 		return NULL;
 
